use actix_session::{storage::RedisSessionStore, SessionMiddleware};
use actix_web::cookie::Key;
use actix_web::{web, App, HttpServer};
use matrix_gateway::app_config::AppConfig;
use matrix_gateway::server::web_ui;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    env_logger::init_from_env(env_logger::Env::new().default_filter_or("info"));

    // FIXME : not scalable
    let secret_key = Key::generate();

    let redis_store = RedisSessionStore::new(AppConfig::get().redis_connection_string())
        .await
        .expect("Failed to connect to Redis!");

    log::info!(
        "Starting to listen on {} for {}",
        AppConfig::get().listen_address,
        AppConfig::get().website_origin
    );
    HttpServer::new(move || {
        App::new()
            // Add session management to your application using Redis for session state storage
            .wrap(SessionMiddleware::new(
                redis_store.clone(),
                secret_key.clone(),
            ))
            // Web configuration routes
            .route("/", web::get().to(web_ui::home))

        // API routes
        // TODO
    })
    .bind(&AppConfig::get().listen_address)?
    .run()
    .await
}
