use crate::app_config::AppConfig;
use crate::constants::{STATE_KEY, USER_SESSION_KEY};
use crate::server::{HttpFailure, HttpResult};
use crate::user::User;
use crate::utils;
use actix_session::Session;
use actix_web::HttpResponse;
use light_openid::primitives::OpenIDConfig;

pub async fn home(session: Session) -> HttpResult {
    // Get user information
    let Some(user): Option<User> = session.get(USER_SESSION_KEY)? else {
        // Generate auth state
        let state = utils::rand_str(10);
        session.insert(STATE_KEY, &state)?;

        let oidc = AppConfig::get().openid_provider();
        let config = OpenIDConfig::load_from_url(oidc.configuration_url)
            .await
            .map_err(HttpFailure::OpenID)?;

        let auth_url = config.gen_authorization_url(oidc.client_id, &state, &oidc.redirect_url);

        return Ok(HttpResponse::Found()
            .append_header(("location", auth_url))
            .finish());
    };

    Ok(HttpResponse::Ok().body("You are authenticated!"))
}
